==> jc-1.4.0.tar.gz: polyglot/ext/jl/qq/QQError.h <==
// public class polyglot.ext.jl.qq.QQError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 909e1b7081315382 polyglot_ext_jl_qq_QQError
// @dep_class 22b321d488641c54 polyglot_util_InternalCompilerError

// header file dependencies
// @dep_header polyglot_util_InternalCompilerError

#include "polyglot/util/InternalCompilerError.h"

#ifndef _JC_polyglot_ext_jl_qq_QQError_H_
#define _JC_polyglot_ext_jl_qq_QQError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_qq_QQError$sub_refs	_jc_polyglot_ext_jl_qq_QQError$sub_refs;
typedef struct _jc_polyglot_ext_jl_qq_QQError$sub_nonrefs	_jc_polyglot_ext_jl_qq_QQError$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_QQError$refs	_jc_polyglot_ext_jl_qq_QQError$refs;
typedef struct _jc_polyglot_ext_jl_qq_QQError$nonrefs	_jc_polyglot_ext_jl_qq_QQError$nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_QQError$object	_jc_polyglot_ext_jl_qq_QQError$object;

typedef const struct _jc_polyglot_ext_jl_qq_QQError$vmethods	_jc_polyglot_ext_jl_qq_QQError$vmethods;
typedef const struct _jc_polyglot_ext_jl_qq_QQError$vtable	_jc_polyglot_ext_jl_qq_QQError$vtable;
typedef const struct _jc_polyglot_ext_jl_qq_QQError$vtype	_jc_polyglot_ext_jl_qq_QQError$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_qq_QQError$method$_init$554f76f5bea40c52(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQError$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *);

// Virtual methods structure
struct _jc_polyglot_ext_jl_qq_QQError$vmethods {
};

// Vtable
struct _jc_polyglot_ext_jl_qq_QQError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_polyglot_util_InternalCompilerError$vmethods	polyglot_util_InternalCompilerError;
	_jc_polyglot_ext_jl_qq_QQError$vmethods	polyglot_ext_jl_qq_QQError;
};

// Vtype
struct _jc_polyglot_ext_jl_qq_QQError$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_qq_QQError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_QQError$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_QQError$refs {
    _jc_polyglot_ext_jl_qq_QQError$sub_refs	polyglot_ext_jl_qq_QQError;
    _jc_polyglot_util_InternalCompilerError$sub_refs	polyglot_util_InternalCompilerError;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_QQError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_QQError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_polyglot_util_InternalCompilerError$sub_nonrefs	polyglot_util_InternalCompilerError;
    _jc_polyglot_ext_jl_qq_QQError$sub_nonrefs	polyglot_ext_jl_qq_QQError;
};

// Object instance structure
struct _jc_polyglot_ext_jl_qq_QQError$object {
	_jc_polyglot_ext_jl_qq_QQError$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_qq_QQError$vtype	*vtype;
	_jc_polyglot_ext_jl_qq_QQError$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_qq_QQError$vtype _jc_polyglot_ext_jl_qq_QQError$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_qq_QQError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_qq_QQError$class_object;

#endif	/* _JC_polyglot_ext_jl_qq_QQError_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/qq/QQError.h <==
// public class polyglot.ext.jl.qq.QQError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 909e1b7081315382 polyglot_ext_jl_qq_QQError
// @dep_class 22b321d488641c54 polyglot_util_InternalCompilerError

// header file dependencies
// @dep_header polyglot_util_InternalCompilerError

#include "polyglot/util/InternalCompilerError.h"

#ifndef _JC_polyglot_ext_jl_qq_QQError_H_
#define _JC_polyglot_ext_jl_qq_QQError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_qq_QQError$sub_refs	_jc_polyglot_ext_jl_qq_QQError$sub_refs;
typedef struct _jc_polyglot_ext_jl_qq_QQError$sub_nonrefs	_jc_polyglot_ext_jl_qq_QQError$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_QQError$refs	_jc_polyglot_ext_jl_qq_QQError$refs;
typedef struct _jc_polyglot_ext_jl_qq_QQError$nonrefs	_jc_polyglot_ext_jl_qq_QQError$nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_QQError$object	_jc_polyglot_ext_jl_qq_QQError$object;

typedef const struct _jc_polyglot_ext_jl_qq_QQError$vmethods	_jc_polyglot_ext_jl_qq_QQError$vmethods;
typedef const struct _jc_polyglot_ext_jl_qq_QQError$vtable	_jc_polyglot_ext_jl_qq_QQError$vtable;
typedef const struct _jc_polyglot_ext_jl_qq_QQError$vtype	_jc_polyglot_ext_jl_qq_QQError$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_qq_QQError$method$_init$554f76f5bea40c52(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQError$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_ext_jl_qq_QQError$vmethods {
};

// Vtable
struct _jc_polyglot_ext_jl_qq_QQError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_polyglot_util_InternalCompilerError$vmethods	polyglot_util_InternalCompilerError;
	_jc_polyglot_ext_jl_qq_QQError$vmethods	polyglot_ext_jl_qq_QQError;
};

// Vtype
struct _jc_polyglot_ext_jl_qq_QQError$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_qq_QQError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_QQError$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_QQError$refs {
    _jc_polyglot_ext_jl_qq_QQError$sub_refs	polyglot_ext_jl_qq_QQError;
    _jc_polyglot_util_InternalCompilerError$sub_refs	polyglot_util_InternalCompilerError;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_QQError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_QQError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_polyglot_util_InternalCompilerError$sub_nonrefs	polyglot_util_InternalCompilerError;
    _jc_polyglot_ext_jl_qq_QQError$sub_nonrefs	polyglot_ext_jl_qq_QQError;
};

// Object instance structure
struct _jc_polyglot_ext_jl_qq_QQError$object {
	_jc_polyglot_ext_jl_qq_QQError$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_qq_QQError$vtype	*vtype;
	_jc_polyglot_ext_jl_qq_QQError$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_qq_QQError$vtype _jc_polyglot_ext_jl_qq_QQError$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_qq_QQError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_qq_QQError$class_object;

#endif	/* _JC_polyglot_ext_jl_qq_QQError_H_ */
